@@ -1,15 +1,12 @@
 #!/usr/bin/env python3
 
-import xmlrpc.client
 import os
 import argparse
-import subprocess
 import signal
 
 import xmlrpc.client
 import http.client
 import socket
-import os
 
 SERVER_SOCKET = "/tmp/batch_queue.sock"
 
@@ -125,6 +122,16 @@ def resume_tasks(task_ids):
         except xmlrpc.client.Fault as err:
             print(f"Failed to resume tasks: {err}")
 
+def set_cpus(ncpus):
+    transport = UnixStreamTransport(SERVER_SOCKET)
+
+    with xmlrpc.client.ServerProxy("http://localhost", transport=transport, allow_none=True) as proxy:
+        try:
+            result = proxy.set_cpus(ncpus)
+            print ('cpus set successfully')
+        except xmlrpc.client.Fault as err:
+            print(f"Failed to set cpus: {err}")
+
 def stop_server():
     transport = UnixStreamTransport(SERVER_SOCKET)
 
@@ -136,8 +143,6 @@ def stop_server():
         except xmlrpc.client.Fault as err:
             print(f"Failed to stop server: {err}")
 
-SOCKET_PATH = "/tmp/batch_queue.sock"
-
 def start_server(max_cpus):
     """Start the batch queue server."""
     import os
@@ -197,6 +202,10 @@ def main():
     resume_parser = subparsers.add_parser("resume", help="Resume a paused task")
     resume_parser.add_argument("task_ids", type=int, nargs='+', help="The IDs of the tasks to resume")
 
+    # set_cpus command
+    ncpus_parser = subparsers.add_parser("setcpus", help="set #cpus")
+    ncpus_parser.add_argument("ncpus", type=int, help="The #cpus")
+
     # Stop server command
     stop_parser = subparsers.add_parser("stop", help="Stop the server")
 
@@ -216,6 +225,8 @@ def main():
         suspend_tasks(args.task_ids)
     elif args.command == "resume":
         resume_tasks(args.task_ids)
+    elif args.command == "setcpus":
+        set_cpus(args.ncpus)
     elif args.command == "stop":
         stop_server()
     else:
